<?php

namespace Drupal\video_toolbox\Controller;

use Drupal\Core\Url;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Render\FormattableMarkup;

/**
 * Controller for videos list report.
 */
class VideoToolBoxReportController extends ControllerBase {

  /**
   * Creates the report page.
   *
   * @return array
   *   Render array for report output.
   */
  public function report() {
    $content = [];
    $content['message'] = [
      '#markup' => $this->t('Below is a list of all uploaded videos including user, video description, video format, video link and video upload date.'),
    ];
    $headers = [
      $this->t('User'),
      $this->t('Description'),
      $this->t('Link'),
      $this->t('Uploaded date'),
      $this->t('Format'),
    ];
    $videos = \Drupal::service('video.get_service')->getVideosInfo();
    $rows = [];

    foreach ($videos as $entry) {

      if (strlen($entry['description']) > 20) {
        $entry['description'] = substr($entry['description'], 0, 20) . '...';
      }

      $url = Url::fromRoute('video_toolbox.videos_url', ['video_id' => $entry['video_key']])->toString();
      $rows[] = [
        $entry['name'],
        $entry['description'],
        $entry['video_key'] = new FormattableMarkup('<a href=":link">@name</a>',
        [
          ':link' => $url,
          '@name' => $entry['filename'],
        ]),
        date("d/m/Y", $entry['upload_date']),
        $entry['filemime'],
      ];
    }
    $content['table'] = [
      '#type' => 'table',
      '#header' => $headers,
      '#rows' => $rows,
      '#empty' => $this->t('No entries available'),
    ];
    // Don't cache this page.
    $content['#cache']['max-age'] = 0;
    return $content;
  }

}
