<?php

namespace Drupal\video_toolbox\Form;

use Drupal\file\Entity\File;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Video toolbox form.
 */
class VideosUrlForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'video_default_url';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $video_id = NULL) {

    $videogetter = \Drupal::service('video.get_service');
    $videos = $videogetter->getVideoInfo($video_id);

    $current_user = \Drupal::currentUser();
    $uid = $current_user->id();
    $roles = $current_user->getRoles();

    if ($videos[0]['uid'] != $uid || !array_search("administrator", $roles)) {

      $file = File::load($videos[0]['fid']);
      $videourl = $file->createFileUrl();
      $form['video' . $video_id] = [
        '#type' => 'html_tag',
        '#tag' => 'video',
        '#attributes' => [
          'src' => $videourl,
          'allow' => 'fullscreen',
          'width' => 420,
          'height' => 315,
          'loading' => 'eager',
          'controls' => 'true',
        ],
      ];
      return $form;
    }

    $file = File::load($videos[0]['fid']);
    $videourl = $file->createFileUrl();
    $form['video' . $video_id] = [
      '#type' => 'html_tag',
      '#tag' => 'video',
      '#attributes' => [
        'src' => $videourl,
        'allow' => 'fullscreen',
        'width' => 420,
        'height' => 315,
        'loading' => 'eager',
        'controls' => 'true',
      ],
    ];

    $form['description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Description'),
      '#required' => TRUE,
      '#default_value' => $videos[0]['description'],
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    $form['download'] = [
      '#type' => 'button',
      '#value' => $this->t('Download'),
      '#submit' => ['downloadFunc'],
    ];

    $form['fid'] = [
      '#type' => 'hidden',
      '#value' => $videos[0]['fid'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $desc = $form_state->getValue('description');
    if (is_string($desc) && mb_strlen($desc) < 10) {
      $form_state->setErrorByName('description', $this->t('Description should be at least 10 characters.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $desc = $form_state->getValue('description');
    $fid = $form_state->getValue('fid');
    $videogetter = \Drupal::service('video.get_service');
    $videogetter->updateVideos($desc, $fid);

    $this->messenger()->addStatus($this->t('Description saved'));
  }

  /**
   * Download video.
   */
  public function downloadFunc(FormStateInterface $form_state) {

    $desc = $form_state->getValue('description');
    $fid = $form_state->getValue('fid');
    $videogetter = \Drupal::service('video.get_service');
    $videogetter->updateVideos($desc, $fid);

    $this->messenger()->addStatus($this->t('Description saved'));
  }

}
